from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class RestrictedDiet(Enumeration):
    """A diet restricted to certain foods or preparations for cultural, religious, health or lifestyle reasons.

    See: https://schema.org/RestrictedDiet
    Model depth: 4
    """

    type_: str = Field(default="RestrictedDiet", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.BioChemEntity import BioChemEntity


class Protein(BioChemEntity):
    """Protein is here used in its widest possible definition, as classes of amino acid based molecules. Amyloid-beta
     Protein in human (UniProt P05067), eukaryota (e.g. an OrthoDB group) or even a single molecule that one can
     point to are all of type :Protein. A protein can thus be a subclass of another protein, e.g. :Protein as a UniProt
     record can have multiple isoforms inside it which would also be :Protein. They can be imagined, synthetic,
     hypothetical or naturally occurring.

    See: https://schema.org/Protein
    Model depth: 3
    """

    type_: str = Field(default="Protein", alias="@type", const=True)
    hasBioPolymerSequence: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="A symbolic representation of a BioChemEntity. For example, a nucleotide sequence of a Gene or an amino acid sequence of a Protein.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalGuideline import MedicalGuideline


class MedicalGuidelineContraindication(MedicalGuideline):
    """A guideline contraindication that designates a process as harmful and where quality of the data supporting
     the contraindication is sound.

    See: https://schema.org/MedicalGuidelineContraindication
    Model depth: 4
    """

    type_: str = Field(
        default="MedicalGuidelineContraindication", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Role import Role


class LinkRole(Role):
    """A Role that represents a Web link, e.g. as expressed via the 'url' property. Its linkRelationship property
     can indicate URL-based and plain textual link types, e.g. those in IANA link registry or others such as 'amphtml'.
     This structure provides a placeholder where details from HTML's link element can be represented outside
     of HTML, e.g. in JSON-LD feeds.

    See: https://schema.org/LinkRole
    Model depth: 4
    """

    type_: str = Field(default="LinkRole", alias="@type", const=True)
    inLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]].",
    )
    linkRelationship: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Indicates the relationship type of a Web link.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SizeGroupEnumeration import SizeGroupEnumeration


class WearableSizeGroupEnumeration(SizeGroupEnumeration):
    """Enumerates common size groups (also known as \"size types\") for wearable products.

    See: https://schema.org/WearableSizeGroupEnumeration
    Model depth: 5
    """

    type_: str = Field(
        default="WearableSizeGroupEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class AdultOrientedEnumeration(Enumeration):
    """Enumeration of considerations that make a product relevant or potentially restricted for adults only.

    See: https://schema.org/AdultOrientedEnumeration
    Model depth: 4
    """

    type_: str = Field(default="AdultOrientedEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EducationalOrganization import EducationalOrganization


class ElementarySchool(EducationalOrganization):
    """An elementary school.

    See: https://schema.org/ElementarySchool
    Model depth: 4
    """

    type_: str = Field(default="ElementarySchool", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Text import Text


class CssSelectorType(Text):
    """Text representing a CSS selector.

    See: https://schema.org/CssSelectorType
    Model depth: 6
    """

    type_: str = Field(default="CssSelectorType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemAvailability import ItemAvailability


class PreSale(ItemAvailability):
    """Indicates that the item is available for ordering and delivery before general availability.

    See: https://schema.org/PreSale
    Model depth: 5
    """

    type_: str = Field(default="PreSale", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InsertAction import InsertAction


class PrependAction(InsertAction):
    """The act of inserting at the beginning if an ordered collection.

    See: https://schema.org/PrependAction
    Model depth: 6
    """

    type_: str = Field(default="PrependAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.UserInteraction import UserInteraction


class UserComments(UserInteraction):
    """UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally
     better to use [[Action]]-based vocabulary, alongside types such as [[Comment]].

    See: https://schema.org/UserComments
    Model depth: 4
    """

    type_: str = Field(default="UserComments", alias="@type", const=True)
    creator: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork.",
    )
    discusses: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="Specifies the CreativeWork associated with the UserComment.",
    )
    commentTime: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The time at which the UserComment was made.",
    )
    commentText: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The text of the UserComment.",
    )
    replyToUrl: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = (
        Field(
            default=None,
            description="The URL at which a reply may be posted to the specified UserComment.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicineSystem import MedicineSystem


class Chiropractic(MedicineSystem):
    """A system of medicine focused on the relationship between the body's structure, mainly the spine, and its functioning.

    See: https://schema.org/Chiropractic
    Model depth: 6
    """

    type_: str = Field(default="Chiropractic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Vessel import Vessel


class Artery(Vessel):
    """A type of blood vessel that specifically carries blood away from the heart.

    See: https://schema.org/Artery
    Model depth: 5
    """

    type_: str = Field(default="Artery", alias="@type", const=True)
    arterialBranch: Optional[
        Union[List[Union["AnatomicalStructure", str]], "AnatomicalStructure", str]
    ] = Field(
        default=None,
        description="The branches that comprise the arterial structure.",
    )
    supplyTo: Optional[
        Union[List[Union["AnatomicalStructure", str]], "AnatomicalStructure", str]
    ] = Field(
        default=None,
        description="The area to which the artery supplies blood.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct
from pydantic2_schemaorg.PaymentMethod import PaymentMethod


class PaymentCard(FinancialProduct, PaymentMethod):
    """A payment method using a credit, debit, store or other card to associate the payment with an account.

    See: https://schema.org/PaymentCard
    Model depth: 4
    """

    type_: str = Field(default="PaymentCard", alias="@type", const=True)
    floorLimit: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="A floor limit is the amount of money above which credit card transactions must be authorized.",
    )
    contactlessPayment: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="A secure method for consumers to purchase products or services via debit, credit or smartcards by using RFID or NFC technology.",
    )
    cashBack: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", StrictBool, "Boolean", str]],
            StrictInt,
            StrictFloat,
            "Number",
            StrictBool,
            "Boolean",
            str,
        ]
    ] = Field(
        default=None,
        description="A cardholder benefit that pays the cardholder a small percentage of their net expenditures.",
    )
    monthlyMinimumRepaymentAmount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EnergyStarEnergyEfficiencyEnumeration import (
    EnergyStarEnergyEfficiencyEnumeration,
)


class EnergyStarCertified(EnergyStarEnergyEfficiencyEnumeration):
    """Represents EnergyStar certification.

    See: https://schema.org/EnergyStarCertified
    Model depth: 6
    """

    type_: str = Field(default="EnergyStarCertified", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Vehicle import Vehicle


class MotorizedBicycle(Vehicle):
    """A motorized bicycle is a bicycle with an attached motor used to power the vehicle, or to assist with pedaling.

    See: https://schema.org/MotorizedBicycle
    Model depth: 4
    """

    type_: str = Field(default="MotorizedBicycle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class Emergency(MedicalSpecialty, MedicalBusiness):
    """A specific branch of medical science that deals with the evaluation and initial treatment of medical conditions
     caused by trauma or sudden illness.

    See: https://schema.org/Emergency
    Model depth: 5
    """

    type_: str = Field(default="Emergency", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class PaymentMethod(Intangible):
    """A payment method is a standardized procedure for transferring the monetary amount for a purchase. Payment
     methods are characterized by the legal and technical structures used, and by the organization or group carrying
     out the transaction. The following legacy values should be accepted: * http://purl.org/goodrelations/v1#ByBankTransferInAdvance
     * http://purl.org/goodrelations/v1#ByInvoice * http://purl.org/goodrelations/v1#Cash * http://purl.org/goodrelations/v1#CheckInAdvance
     * http://purl.org/goodrelations/v1#COD * http://purl.org/goodrelations/v1#DirectDebit * http://purl.org/goodrelations/v1#GoogleCheckout
     * http://purl.org/goodrelations/v1#PayPal * http://purl.org/goodrelations/v1#PaySwarm Structured
     values are recommended for newer payment methods.

    See: https://schema.org/PaymentMethod
    Model depth: 3
    """

    type_: str = Field(default="PaymentMethod", alias="@type", const=True)
    paymentMethodType: Optional[
        Union[List[Union["PaymentMethodType", str]], "PaymentMethodType", str]
    ] = Field(
        default=None,
        description="The type of a payment method.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.PaymentMethodType import PaymentMethodType



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Physician import Physician


class IndividualPhysician(Physician):
    """An individual medical practitioner. For their official address use [[address]], for affiliations to hospitals
     use [[hospitalAffiliation]]. The [[practicesAt]] property can be used to indicate [[MedicalOrganization]]
     hospitals, clinics, pharmacies etc. where this physician practices.

    See: https://schema.org/IndividualPhysician
    Model depth: 5
    """

    type_: str = Field(default="IndividualPhysician", alias="@type", const=True)
    practicesAt: Optional[
        Union[List[Union["MedicalOrganization", str]], "MedicalOrganization", str]
    ] = Field(
        default=None,
        description="A [[MedicalOrganization]] where the [[IndividualPhysician]] practices.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalOrganization import MedicalOrganization



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration


class ReturnInStore(ReturnMethodEnumeration):
    """Specifies that product returns must be made in a store.

    See: https://schema.org/ReturnInStore
    Model depth: 5
    """

    type_: str = Field(default="ReturnInStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
    MedicalObservationalStudyDesign,
)


class Longitudinal(MedicalObservationalStudyDesign):
    """Unlike cross-sectional studies, longitudinal studies track the same people, and therefore the differences
     observed in those people are less likely to be the result of cultural differences across generations. Longitudinal
     studies are also used in medicine to uncover predictors of certain diseases.

    See: https://schema.org/Longitudinal
    Model depth: 6
    """

    type_: str = Field(default="Longitudinal", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class EventAttendanceModeEnumeration(Enumeration):
    """An EventAttendanceModeEnumeration value is one of potentially several modes of organising an event, relating
     to whether it is online or offline.

    See: https://schema.org/EventAttendanceModeEnumeration
    Model depth: 4
    """

    type_: str = Field(
        default="EventAttendanceModeEnumeration", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Series import Series
from pydantic2_schemaorg.CreativeWork import CreativeWork


class CreativeWorkSeries(Series, CreativeWork):
    """A CreativeWorkSeries in schema.org is a group of related items, typically but not necessarily of the same
     kind. CreativeWorkSeries are usually organized into some order, often chronological. Unlike [[ItemList]]
     which is a general purpose data structure for lists of things, the emphasis with CreativeWorkSeries is on
     published materials (written e.g. books and periodicals, or media such as TV, radio and games). Specific
     subtypes are available for describing [[TVSeries]], [[RadioSeries]], [[MovieSeries]], [[BookSeries]],
     [[Periodical]] and [[VideoGameSeries]]. In each case, the [[hasPart]] / [[isPartOf]] properties can be
     used to relate the CreativeWorkSeries to its parts. The general CreativeWorkSeries type serves largely
     just to organize these more specific and practical subtypes. It is common for properties applicable to an
     item from the series to be usefully applied to the containing group. Schema.org attempts to anticipate some
     of these cases, but publishers should be free to apply properties of the series parts to the series as a whole
     wherever they seem appropriate.

    See: https://schema.org/CreativeWorkSeries
    Model depth: 3
    """

    type_: str = Field(default="CreativeWorkSeries", alias="@type", const=True)
    issn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.",
    )
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class FinancialService(LocalBusiness):
    """Financial services business.

    See: https://schema.org/FinancialService
    Model depth: 4
    """

    type_: str = Field(default="FinancialService", alias="@type", const=True)
    feesAndCommissionsSpecification: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Description of fees, commissions, and other terms applied either to a class of financial product, or by a financial service organization.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class OriginalMediaContent(MediaManipulationRatingEnumeration):
    """Content coded 'as original media content' in a [[MediaReview]], considered in the context of how it was published
     or shared. For a [[VideoObject]] to be 'original': No evidence the footage has been misleadingly altered
     or manipulated, though it may contain false or misleading claims. For an [[ImageObject]] to be 'original':
     No evidence the image has been misleadingly altered or manipulated, though it may still contain false or misleading
     claims. For an [[ImageObject]] with embedded text to be 'original': No evidence the image has been misleadingly
     altered or manipulated, though it may still contain false or misleading claims. For an [[AudioObject]] to
     be 'original': No evidence the audio has been misleadingly altered or manipulated, though it may contain
     false or misleading claims.

    See: https://schema.org/OriginalMediaContent
    Model depth: 5
    """

    type_: str = Field(default="OriginalMediaContent", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class AnimalShelter(LocalBusiness):
    """Animal shelter.

    See: https://schema.org/AnimalShelter
    Model depth: 4
    """

    type_: str = Field(default="AnimalShelter", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject


class MusicVideoObject(MediaObject):
    """A music video file.

    See: https://schema.org/MusicVideoObject
    Model depth: 4
    """

    type_: str = Field(default="MusicVideoObject", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class OnlineBusiness(Organization):
    """A particular online business, either standalone or the online part of a broader organization. Examples include
     an eCommerce site, an online travel booking site, an online learning site, an online logistics and shipping
     provider, an online (virtual) doctor, etc.

    See: https://schema.org/OnlineBusiness
    Model depth: 3
    """

    type_: str = Field(default="OnlineBusiness", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ScholarlyArticle import ScholarlyArticle


class MedicalScholarlyArticle(ScholarlyArticle):
    """A scholarly article in the medical domain.

    See: https://schema.org/MedicalScholarlyArticle
    Model depth: 5
    """

    type_: str = Field(default="MedicalScholarlyArticle", alias="@type", const=True)
    publicationType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The type of the medical article, taken from the US NLM MeSH publication type catalog. See also [MeSH documentation](http://www.nlm.nih.gov/mesh/pubtypes.html).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyOfWater import BodyOfWater


class Canal(BodyOfWater):
    """A canal, like the Panama Canal.

    See: https://schema.org/Canal
    Model depth: 5
    """

    type_: str = Field(default="Canal", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PriceComponentTypeEnumeration import (
    PriceComponentTypeEnumeration,
)


class DistanceFee(PriceComponentTypeEnumeration):
    """Represents the distance fee (e.g., price per km or mile) part of the total price for an offered product, for
     example a car rental.

    See: https://schema.org/DistanceFee
    Model depth: 5
    """

    type_: str = Field(default="DistanceFee", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class TransformedContent(MediaManipulationRatingEnumeration):
    """Content coded 'transformed content' in a [[MediaReview]], considered in the context of how it was published
     or shared. For a [[VideoObject]] to be 'transformed content': or all of the video has been manipulated to transform
     the footage itself. This category includes using tools like the Adobe Suite to change the speed of the video,
     add or remove visual elements or dub audio. Deepfakes are also a subset of transformation. For an [[ImageObject]]
     to be 'transformed content': Adding or deleting visual elements to give the image a different meaning with
     the intention to mislead. For an [[ImageObject]] with embedded text to be 'transformed content': Adding
     or deleting visual elements to give the image a different meaning with the intention to mislead. For an [[AudioObject]]
     to be 'transformed content': Part or all of the audio has been manipulated to alter the words or sounds, or the
     audio has been synthetically generated, such as to create a sound-alike voice.

    See: https://schema.org/TransformedContent
    Model depth: 5
    """

    type_: str = Field(default="TransformedContent", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Comment(CreativeWork):
    """A comment on an item - for example, a comment on a blog post. The comment's content is expressed via the [[text]]
     property, and its topic via [[about]], properties shared with all CreativeWorks.

    See: https://schema.org/Comment
    Model depth: 3
    """

    type_: str = Field(default="Comment", alias="@type", const=True)
    parentItem: Optional[
        Union[
            List[Union["Comment", "CreativeWork", str]], "Comment", "CreativeWork", str
        ]
    ] = Field(
        default=None,
        description="The parent of a question, answer or item in general. Typically used for Q/A discussion threads e.g. a chain of comments with the first comment being an [[Article]] or other [[CreativeWork]]. See also [[comment]] which points from something to a comment about it.",
    )
    sharedContent: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="A CreativeWork such as an image, video, or audio clip shared as part of this posting.",
    )
    upvoteCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of upvotes this question, answer or comment has received from the community.",
    )
    downvoteCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of downvotes this question, answer or comment has received from the community.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration


class FullRefund(RefundTypeEnumeration):
    """Specifies that a refund can be done in the full amount the customer paid for the product.

    See: https://schema.org/FullRefund
    Model depth: 5
    """

    type_: str = Field(default="FullRefund", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableMeasurementTypeEnumeration import (
    WearableMeasurementTypeEnumeration,
)


class WearableMeasurementWidth(WearableMeasurementTypeEnumeration):
    """Measurement of the width, for example of shoes.

    See: https://schema.org/WearableMeasurementWidth
    Model depth: 6
    """

    type_: str = Field(default="WearableMeasurementWidth", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NonprofitType import NonprofitType


class UKNonprofitType(NonprofitType):
    """UKNonprofitType: Non-profit organization type originating from the United Kingdom.

    See: https://schema.org/UKNonprofitType
    Model depth: 5
    """

    type_: str = Field(default="UKNonprofitType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class SpeakableSpecification(Intangible):
    """A SpeakableSpecification indicates (typically via [[xpath]] or [[cssSelector]]) sections of a document
     that are highlighted as particularly [[speakable]]. Instances of this type are expected to be used primarily
     as values of the [[speakable]] property.

    See: https://schema.org/SpeakableSpecification
    Model depth: 3
    """

    type_: str = Field(default="SpeakableSpecification", alias="@type", const=True)
    xpath: Optional[Union[List[Union[str, "XPathType"]], str, "XPathType"]] = Field(
        default=None,
        description='An XPath, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".',
    )
    cssSelector: Optional[
        Union[List[Union[str, "CssSelectorType"]], str, "CssSelectorType"]
    ] = Field(
        default=None,
        description='A CSS selector, e.g. of a [[SpeakableSpecification]] or [[WebPageElement]]. In the latter case, multiple matches within a page can constitute a single conceptual "Web page element".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.XPathType import XPathType
    from pydantic2_schemaorg.CssSelectorType import CssSelectorType



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class MusicPlaylist(CreativeWork):
    """A collection of music tracks in playlist form.

    See: https://schema.org/MusicPlaylist
    Model depth: 3
    """

    type_: str = Field(default="MusicPlaylist", alias="@type", const=True)
    tracks: Optional[
        Union[List[Union["MusicRecording", str]], "MusicRecording", str]
    ] = Field(
        default=None,
        description="A music recording (track)&#x2014;usually a single song.",
    )
    numTracks: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of tracks in this album or playlist.",
    )
    track: Optional[
        Union[
            List[Union["ItemList", "MusicRecording", str]],
            "ItemList",
            "MusicRecording",
            str,
        ]
    ] = Field(
        default=None,
        description="A music recording (track)&#x2014;usually a single song. If an ItemList is given, the list should contain items of type MusicRecording.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MusicRecording import MusicRecording
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.ItemList import ItemList



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemList import ItemList


class BreadcrumbList(ItemList):
    """A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least
     their URL and their name, and typically ending with the current page. The [[position]] property is used to
     reconstruct the order of the items in a BreadcrumbList. The convention is that a breadcrumb list has an [[itemListOrder]]
     of [[ItemListOrderAscending]] (lower values listed first), and that the first items in this list correspond
     to the \"top\" or beginning of the breadcrumb trail, e.g. with a site or section homepage. The specific values
     of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning
     with '1' for the first item in the list.

    See: https://schema.org/BreadcrumbList
    Model depth: 4
    """

    type_: str = Field(default="BreadcrumbList", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c1(USNonprofitType):
    """Nonprofit501c1: Non-profit type referring to Corporations Organized Under Act of Congress, including
     Federal Credit Unions and National Farm Loan Associations.

    See: https://schema.org/Nonprofit501c1
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c1", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementFoot(BodyMeasurementTypeEnumeration):
    """Foot length (measured between end of the most prominent toe and the most prominent part of the heel). Used,
     for example, to measure socks.

    See: https://schema.org/BodyMeasurementFoot
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementFoot", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class UserReview(Review):
    """A review created by an end-user (e.g. consumer, purchaser, attendee etc.), in contrast with [[CriticReview]].

    See: https://schema.org/UserReview
    Model depth: 4
    """

    type_: str = Field(default="UserReview", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool
from datetime import date, datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ActionAccessSpecification(Intangible):
    """A set of requirements that must be fulfilled in order to perform an Action.

    See: https://schema.org/ActionAccessSpecification
    Model depth: 3
    """

    type_: str = Field(default="ActionAccessSpecification", alias="@type", const=True)
    eligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid. See also [[ineligibleRegion]].",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    availabilityEnds: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end of the availability of the product or service included in the offer.",
    )
    expectsAcceptanceOf: Optional[Union[List[Union["Offer", str]], "Offer", str]] = (
        Field(
            default=None,
            description="An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.",
        )
    )
    availabilityStarts: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", date, "Date", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The beginning of the availability of the product or service included in the offer.",
    )
    requiresSubscription: Optional[
        Union[
            List[Union[StrictBool, "Boolean", "MediaSubscription", str]],
            StrictBool,
            "Boolean",
            "MediaSubscription",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates if use of the media require a subscription (either paid or free). Allowed values are ```true``` or ```false``` (note that an earlier version had 'yes', 'no').",
    )
    ineligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed. See also [[eligibleRegion]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Offer import Offer
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.MediaSubscription import MediaSubscription



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class DeliveryTimeSettings(StructuredValue):
    """A DeliveryTimeSettings represents re-usable pieces of shipping information, relating to timing. It is
     designed for publication on an URL that may be referenced via the [[shippingSettingsLink]] property of an
     [[OfferShippingDetails]]. Several occurrences can be published, distinguished (and identified/referenced)
     by their different values for [[transitTimeLabel]].

    See: https://schema.org/DeliveryTimeSettings
    Model depth: 4
    """

    type_: str = Field(default="DeliveryTimeSettings", alias="@type", const=True)
    isUnlabelledFallback: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.",
    )
    shippingDestination: Optional[
        Union[List[Union["DefinedRegion", str]], "DefinedRegion", str]
    ] = Field(
        default=None,
        description="indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.",
    )
    deliveryTime: Optional[
        Union[List[Union["ShippingDeliveryTime", str]], "ShippingDeliveryTime", str]
    ] = Field(
        default=None,
        description="The total delay between the receipt of the order and the goods reaching the final customer.",
    )
    transitTimeLabel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Label to match an [[OfferShippingDetails]] with a [[DeliveryTimeSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.DefinedRegion import DefinedRegion
    from pydantic2_schemaorg.ShippingDeliveryTime import ShippingDeliveryTime
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.IPTCDigitalSourceEnumeration import (
    IPTCDigitalSourceEnumeration,
)


class AlgorithmicMediaDigitalSource(IPTCDigitalSourceEnumeration):
    """Content coded as '<a href=\"https://cv.iptc.org/newscodes/digitalsourcetype/algorithmicMedia\">algorithmic
     media</a>' using the IPTC <a href=\"https://cv.iptc.org/newscodes/digitalsourcetype/\">digital
     source type</a> vocabulary.

    See: https://schema.org/AlgorithmicMediaDigitalSource
    Model depth: 6
    """

    type_: str = Field(
        default="AlgorithmicMediaDigitalSource", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReservationStatusType import ReservationStatusType


class ReservationPending(ReservationStatusType):
    """The status of a reservation when a request has been sent, but not confirmed.

    See: https://schema.org/ReservationPending
    Model depth: 6
    """

    type_: str = Field(default="ReservationPending", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class GovernmentBenefitsType(Enumeration):
    """GovernmentBenefitsType enumerates several kinds of government benefits to support the COVID-19 situation.
     Note that this structure may not capture all benefits offered.

    See: https://schema.org/GovernmentBenefitsType
    Model depth: 4
    """

    type_: str = Field(default="GovernmentBenefitsType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ProgramMembership(Intangible):
    """Used to describe membership in a loyalty programs (e.g. \"StarAliance\"), traveler clubs (e.g. \"AAA\"),
     purchase clubs (\"Safeway Club\"), etc.

    See: https://schema.org/ProgramMembership
    Model depth: 3
    """

    type_: str = Field(default="ProgramMembership", alias="@type", const=True)
    members: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A member of this organization.",
    )
    member: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals.",
    )
    membershipPointsEarned: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)",
    )
    programName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The program providing the membership. It is preferable to use [:program](https://schema.org/program) instead.",
    )
    hostingOrganization: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The Organization (airline, travelers' club, retailer, etc.) the membership is made with or which offers the MemberProgram.",
    )
    membershipNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A unique identifier for the membership.",
    )
    program: Optional[
        Union[List[Union["MemberProgram", str]], "MemberProgram", str]
    ] = Field(
        default=None,
        description="The [MemberProgram](https://schema.org/MemberProgram) associated with a [ProgramMembership](https://schema.org/ProgramMembership).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MemberProgram import MemberProgram



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.ListItem import ListItem
from pydantic2_schemaorg.ItemList import ItemList
from pydantic2_schemaorg.CreativeWork import CreativeWork


class HowToSection(ListItem, ItemList, CreativeWork):
    """A sub-grouping of steps in the instructions for how to achieve a result (e.g. steps for making a pie crust within
     a pie recipe).

    See: https://schema.org/HowToSection
    Model depth: 3
    """

    type_: str = Field(default="HowToSection", alias="@type", const=True)
    steps: Optional[
        Union[
            List[Union[str, "Text", "ItemList", "CreativeWork"]],
            str,
            "Text",
            "ItemList",
            "CreativeWork",
        ]
    ] = Field(
        default=None,
        description="A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally misnamed 'steps'; 'step' is preferred).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.ItemList import ItemList
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class PublicHealth(MedicalSpecialty, MedicalBusiness):
    """Branch of medicine that pertains to the health services to improve and protect community health, especially
     epidemiology, sanitation, immunization, and preventive medicine.

    See: https://schema.org/PublicHealth
    Model depth: 5
    """

    type_: str = Field(default="PublicHealth", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicineSystem import MedicineSystem


class Ayurvedic(MedicineSystem):
    """A system of medicine that originated in India over thousands of years and that focuses on integrating and balancing
     the body, mind, and spirit.

    See: https://schema.org/Ayurvedic
    Model depth: 6
    """

    type_: str = Field(default="Ayurvedic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct
from pydantic2_schemaorg.PaymentMethod import PaymentMethod


class PaymentService(FinancialProduct, PaymentMethod):
    """A Service to transfer funds from a person or organization to a beneficiary person or organization.

    See: https://schema.org/PaymentService
    Model depth: 4
    """

    type_: str = Field(default="PaymentService", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalRiskFactor(MedicalEntity):
    """A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical
     condition, or complication.

    See: https://schema.org/MedicalRiskFactor
    Model depth: 3
    """

    type_: str = Field(default="MedicalRiskFactor", alias="@type", const=True)
    increasesRiskOf: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="The condition, complication, etc. influenced by this factor.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPageElement import WebPageElement


class WPSideBar(WebPageElement):
    """A sidebar section of the page.

    See: https://schema.org/WPSideBar
    Model depth: 4
    """

    type_: str = Field(default="WPSideBar", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class GeospatialGeometry(Intangible):
    """(Eventually to be defined as) a supertype of GeoShape designed to accommodate definitions from Geo-Spatial
     best practices.

    See: https://schema.org/GeospatialGeometry
    Model depth: 3
    """

    type_: str = Field(default="GeospatialGeometry", alias="@type", const=True)
    geoWithin: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to one that contains it, i.e. it is inside (i.e. within) its interior. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    geoCovers: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a covering geometry to a covered geometry. "Every point of b is a point of (the interior or boundary of) a". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    geoOverlaps: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to another that geospatially overlaps it, i.e. they have some but not all points in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    geoDisjoint: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) are topologically disjoint: "they have no point in common. They form a set of disconnected geometries." (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)',
    )
    geoCrosses: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a geometry to another that crosses it: "a crosses b: they have some but not all interior points in common, and the dimension of the intersection is less than that of at least one of them". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    geoTouches: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) touch: "they have at least one boundary point in common, but no interior points." (A symmetric relationship, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)',
    )
    geoContains: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents a relationship between two geometries (or the places they represent), relating a containing geometry to a contained geometry. "a contains b iff no points of b lie in the exterior of a, and at least one point of the interior of b lies in the interior of a". As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).',
    )
    geoCoveredBy: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents a relationship between two geometries (or the places they represent), relating a geometry to another that covers it. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    geoIntersects: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description="Represents spatial relations in which two geometries (or the places they represent) have at least one point in common. As defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).",
    )
    geoEquals: Optional[
        Union[
            List[Union["GeospatialGeometry", "Place", str]],
            "GeospatialGeometry",
            "Place",
            str,
        ]
    ] = Field(
        default=None,
        description='Represents spatial relations in which two geometries (or the places they represent) are topologically equal, as defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Place import Place



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject


class TextObject(MediaObject):
    """A text file. The text can be unformatted or contain markup, html, etc.

    See: https://schema.org/TextObject
    Model depth: 4
    """

    type_: str = Field(default="TextObject", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBusiness


class HVACBusiness(HomeAndConstructionBusiness):
    """A business that provides Heating, Ventilation and Air Conditioning services.

    See: https://schema.org/HVACBusiness
    Model depth: 5
    """

    type_: str = Field(default="HVACBusiness", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class ContactPoint(StructuredValue):
    """A contact point&#x2014;for example, a Customer Complaints department.

    See: https://schema.org/ContactPoint
    Model depth: 4
    """

    type_: str = Field(default="ContactPoint", alias="@type", const=True)
    faxNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The fax number.",
    )
    availableLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]].",
    )
    contactOption: Optional[
        Union[List[Union["ContactPointOption", str]], "ContactPointOption", str]
    ] = Field(
        default=None,
        description="An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers).",
    )
    contactType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point.",
    )
    productSupported: Optional[
        Union[List[Union[str, "Text", "Product"]], str, "Text", "Product"]
    ] = Field(
        default=None,
        description='The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. "iPhone") or a general category of products or services (e.g. "smartphones").',
    )
    serviceArea: Optional[
        Union[
            List[Union["Place", "GeoShape", "AdministrativeArea", str]],
            "Place",
            "GeoShape",
            "AdministrativeArea",
            str,
        ]
    ] = Field(
        default=None,
        description="The geographic area where the service is provided.",
    )
    hoursAvailable: Optional[
        Union[
            List[Union["OpeningHoursSpecification", str]],
            "OpeningHoursSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The hours during which this service or contact is available.",
    )
    email: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Email address.",
    )
    areaServed: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape", "AdministrativeArea"]],
            str,
            "Text",
            "Place",
            "GeoShape",
            "AdministrativeArea",
        ]
    ] = Field(
        default=None,
        description="The geographic area where a service or offered item is provided.",
    )
    telephone: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The telephone number.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.ContactPointOption import ContactPointOption
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.OpeningHoursSpecification import OpeningHoursSpecification



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Urologic(MedicalSpecialty):
    """A specific branch of medical science that is concerned with the diagnosis and treatment of diseases pertaining
     to the urinary tract and the urogenital system.

    See: https://schema.org/Urologic
    Model depth: 6
    """

    type_: str = Field(default="Urologic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class SizeSystemEnumeration(Enumeration):
    """Enumerates common size systems for different categories of products, for example \"EN-13402\" or \"UK\"
     for wearables or \"Imperial\" for screws.

    See: https://schema.org/SizeSystemEnumeration
    Model depth: 4
    """

    type_: str = Field(default="SizeSystemEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AutomotiveBusiness import AutomotiveBusiness


class GasStation(AutomotiveBusiness):
    """A gas station.

    See: https://schema.org/GasStation
    Model depth: 5
    """

    type_: str = Field(default="GasStation", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration


class MedicalProcedureType(MedicalEnumeration):
    """An enumeration that describes different types of medical procedures.

    See: https://schema.org/MedicalProcedureType
    Model depth: 5
    """

    type_: str = Field(default="MedicalProcedureType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class DeliveryEvent(Event):
    """An event involving the delivery of an item.

    See: https://schema.org/DeliveryEvent
    Model depth: 3
    """

    type_: str = Field(default="DeliveryEvent", alias="@type", const=True)
    availableThrough: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="After this date, the item will no longer be available for pickup.",
    )
    hasDeliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="Method used for delivery or shipping.",
    )
    accessCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Password, PIN, or access code needed for delivery (e.g. from a locker).",
    )
    availableFrom: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="When the item is available for pickup from the store, locker, etc.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalProcedure(MedicalEntity):
    """A process of care used in either a diagnostic, therapeutic, preventive or palliative capacity that relies
     on invasive (surgical), non-invasive, or other techniques.

    See: https://schema.org/MedicalProcedure
    Model depth: 3
    """

    type_: str = Field(default="MedicalProcedure", alias="@type", const=True)
    preparation: Optional[
        Union[List[Union[str, "Text", "MedicalEntity"]], str, "Text", "MedicalEntity"]
    ] = Field(
        default=None,
        description="Typical preparation that a patient must undergo before having the procedure performed.",
    )
    howPerformed: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="How the procedure is performed.",
    )
    procedureType: Optional[
        Union[List[Union["MedicalProcedureType", str]], "MedicalProcedureType", str]
    ] = Field(
        default=None,
        description="The type of procedure, for example Surgical, Noninvasive, or Percutaneous.",
    )
    followup: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Typical or recommended followup care after the procedure is performed.",
    )
    bodyLocation: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Location in the body of the anatomical structure.",
    )
    status: Optional[
        Union[
            List[Union[str, "Text", "EventStatusType", "MedicalStudyStatus"]],
            str,
            "Text",
            "EventStatusType",
            "MedicalStudyStatus",
        ]
    ] = Field(
        default=None,
        description="The status of the study (enumerated).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.MedicalProcedureType import MedicalProcedureType
    from pydantic2_schemaorg.EventStatusType import EventStatusType
    from pydantic2_schemaorg.MedicalStudyStatus import MedicalStudyStatus



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BookFormatType import BookFormatType


class AudiobookFormat(BookFormatType):
    """Book format: Audiobook. This is an enumerated value for use with the bookFormat property. There is also a type
     'Audiobook' in the bib extension which includes Audiobook specific properties.

    See: https://schema.org/AudiobookFormat
    Model depth: 5
    """

    type_: str = Field(default="AudiobookFormat", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MediaSubscription(Intangible):
    """A subscription which allows a user to access media including audio, video, books, etc.

    See: https://schema.org/MediaSubscription
    Model depth: 3
    """

    type_: str = Field(default="MediaSubscription", alias="@type", const=True)
    authenticator: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The Organization responsible for authenticating the user's subscription. For example, many media apps require a cable/satellite provider to authenticate your subscription before playing media.",
    )
    expectsAcceptanceOf: Optional[Union[List[Union["Offer", str]], "Offer", str]] = (
        Field(
            default=None,
            description="An Offer which must be accepted before the user can perform the Action. For example, the user may need to buy a movie before being able to watch it.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Landform import Landform


class Continent(Landform):
    """One of the continents (for example, Europe or Africa).

    See: https://schema.org/Continent
    Model depth: 4
    """

    type_: str = Field(default="Continent", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Claim(CreativeWork):
    """A [[Claim]] in Schema.org represents a specific, factually-oriented claim that could be the [[itemReviewed]]
     in a [[ClaimReview]]. The content of a claim can be summarized with the [[text]] property. Variations on well
     known claims can have their common identity indicated via [[sameAs]] links, and summarized with a [[name]].
     Ideally, a [[Claim]] description includes enough contextual information to minimize the risk of ambiguity
     or inclarity. In practice, many claims are better understood in the context in which they appear or the interpretations
     provided by claim reviews. Beyond [[ClaimReview]], the Claim type can be associated with related creative
     works - for example a [[ScholarlyArticle]] or [[Question]] might be [[about]] some [[Claim]]. At this time,
     Schema.org does not define any types of relationship between claims. This is a natural area for future exploration.

    See: https://schema.org/Claim
    Model depth: 3
    """

    type_: str = Field(default="Claim", alias="@type", const=True)
    firstAppearance: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="Indicates the first known occurrence of a [[Claim]] in some [[CreativeWork]].",
    )
    claimInterpreter: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="For a [[Claim]] interpreted from [[MediaObject]] content, the [[interpretedAsClaim]] property can be used to indicate a claim contained, implied or refined from the content of a [[MediaObject]].",
    )
    appearance: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="Indicates an occurrence of a [[Claim]] in some [[CreativeWork]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicPlaylist import MusicPlaylist


class MusicRelease(MusicPlaylist):
    """A MusicRelease is a specific release of a music album.

    See: https://schema.org/MusicRelease
    Model depth: 4
    """

    type_: str = Field(default="MusicRelease", alias="@type", const=True)
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    catalogNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The catalog number for the release.",
    )
    releaseOf: Optional[Union[List[Union["MusicAlbum", str]], "MusicAlbum", str]] = (
        Field(
            default=None,
            description="The album this is a release of.",
        )
    )
    musicReleaseFormat: Optional[
        Union[List[Union["MusicReleaseFormatType", str]], "MusicReleaseFormatType", str]
    ] = Field(
        default=None,
        description="Format of this release (the type of recording media used, i.e. compact disc, digital media, LP, etc.).",
    )
    creditedTo: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description='The group the release is credited to if different than the byArtist. For example, Red and Blue is credited to "Stefani Germanotta Band", but by Lady Gaga.',
    )
    recordLabel: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The label that issued the release.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MusicAlbum import MusicAlbum
    from pydantic2_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class MediaReview(Review):
    """A [[MediaReview]] is a more specialized form of Review dedicated to the evaluation of media content online,
     typically in the context of fact-checking and misinformation. For more general reviews of media in the broader
     sense, use [[UserReview]], [[CriticReview]] or other [[Review]] types. This definition is a work in progress.
     While the [[MediaManipulationRatingEnumeration]] list reflects significant community review amongst
     fact-checkers and others working to combat misinformation, the specific structures for representing media
     objects, their versions and publication context, are still evolving. Similarly, best practices for the
     relationship between [[MediaReview]] and [[ClaimReview]] markup have not yet been finalized.

    See: https://schema.org/MediaReview
    Model depth: 4
    """

    type_: str = Field(default="MediaReview", alias="@type", const=True)
    originalMediaContextDescription: Optional[
        Union[List[Union[str, "Text"]], str, "Text"]
    ] = Field(
        default=None,
        description="Describes, in a [[MediaReview]] when dealing with [[DecontextualizedContent]], background information that can contribute to better interpretation of the [[MediaObject]].",
    )
    originalMediaLink: Optional[
        Union[
            List[Union[AnyUrl, "URL", "MediaObject", "WebPage", str]],
            AnyUrl,
            "URL",
            "MediaObject",
            "WebPage",
            str,
        ]
    ] = Field(
        default=None,
        description="Link to the page containing an original version of the content, or directly to an online copy of the original [[MediaObject]] content, e.g. video file.",
    )
    mediaAuthenticityCategory: Optional[
        Union[
            List[Union["MediaManipulationRatingEnumeration", str]],
            "MediaManipulationRatingEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates a MediaManipulationRatingEnumeration classification of a media object (in the context of how it was published or shared).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MediaObject import MediaObject
    from pydantic2_schemaorg.WebPage import WebPage
    from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
        MediaManipulationRatingEnumeration,
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class EducationalOccupationalCredential(CreativeWork):
    """An educational or occupational credential. A diploma, academic degree, certification, qualification,
     badge, etc., that may be awarded to a person or other entity that meets the requirements defined by the credentialer.

    See: https://schema.org/EducationalOccupationalCredential
    Model depth: 3
    """

    type_: str = Field(
        default="EducationalOccupationalCredential", alias="@type", const=True
    )
    validIn: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The geographic area where the item is valid. Applies for example to a [[Permit]], a [[Certification]], or an [[EducationalOccupationalCredential]].",
    )
    recognizedBy: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="An organization that acknowledges the validity, value or utility of a credential. Note: recognition may include a process of quality assurance or accreditation.",
    )
    educationalLevel: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.",
    )
    competencyRequired: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="Knowledge, skill, ability or personal attribute that must be demonstrated by a person or other entity in order to do something such as earn an Educational Occupational Credential or understand a LearningResource.",
    )
    validFor: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of validity of a permit or similar thing.",
    )
    credentialCategory: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='The category or type of credential being described, for example "degree”, “certificate”, “badge”, or more specific term.',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Duration import Duration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ActionStatusType import ActionStatusType


class PotentialActionStatus(ActionStatusType):
    """A description of an action that is supported.

    See: https://schema.org/PotentialActionStatus
    Model depth: 6
    """

    type_: str = Field(default="PotentialActionStatus", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemAvailability import ItemAvailability


class InStock(ItemAvailability):
    """Indicates that the item is in stock.

    See: https://schema.org/InStock
    Model depth: 5
    """

    type_: str = Field(default="InStock", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class LibrarySystem(Organization):
    """A [[LibrarySystem]] is a collaborative system amongst several libraries.

    See: https://schema.org/LibrarySystem
    Model depth: 3
    """

    type_: str = Field(default="LibrarySystem", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableMeasurementTypeEnumeration import (
    WearableMeasurementTypeEnumeration,
)


class WearableMeasurementLength(WearableMeasurementTypeEnumeration):
    """Represents the length, for example of a dress.

    See: https://schema.org/WearableMeasurementLength
    Model depth: 6
    """

    type_: str = Field(default="WearableMeasurementLength", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration


class KeepProduct(ReturnMethodEnumeration):
    """Specifies that the consumer can keep the product, even when receiving a refund or store credit.

    See: https://schema.org/KeepProduct
    Model depth: 5
    """

    type_: str = Field(default="KeepProduct", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration


class FreeReturn(ReturnFeesEnumeration):
    """Specifies that product returns are free of charge for the customer.

    See: https://schema.org/FreeReturn
    Model depth: 5
    """

    type_: str = Field(default="FreeReturn", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class OrganizeAction(Action):
    """The act of manipulating/administering/supervising/controlling one or more objects.

    See: https://schema.org/OrganizeAction
    Model depth: 3
    """

    type_: str = Field(default="OrganizeAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalPlatformEnumeration import DigitalPlatformEnumeration


class AndroidPlatform(DigitalPlatformEnumeration):
    """Represents the broad notion of Android-based operating systems.

    See: https://schema.org/AndroidPlatform
    Model depth: 5
    """

    type_: str = Field(default="AndroidPlatform", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class DayOfWeek(Enumeration):
    """The day of the week, e.g. used to specify to which day the opening hours of an OpeningHoursSpecification refer.
     Originally, URLs from [GoodRelations](http://purl.org/goodrelations/v1) were used (for [[Monday]],
     [[Tuesday]], [[Wednesday]], [[Thursday]], [[Friday]], [[Saturday]], [[Sunday]] plus a special entry
     for [[PublicHolidays]]); these have now been integrated directly into schema.org.

    See: https://schema.org/DayOfWeek
    Model depth: 4
    """

    type_: str = Field(default="DayOfWeek", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ConsumeAction import ConsumeAction


class DrinkAction(ConsumeAction):
    """The act of swallowing liquids.

    See: https://schema.org/DrinkAction
    Model depth: 4
    """

    type_: str = Field(default="DrinkAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Nerve(AnatomicalStructure):
    """A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons.

    See: https://schema.org/Nerve
    Model depth: 4
    """

    type_: str = Field(default="Nerve", alias="@type", const=True)
    nerveMotor: Optional[Union[List[Union["Muscle", str]], "Muscle", str]] = Field(
        default=None,
        description="The neurological pathway extension that involves muscle control.",
    )
    branch: Optional[
        Union[List[Union["AnatomicalStructure", str]], "AnatomicalStructure", str]
    ] = Field(
        default=None,
        description="The branches that delineate from the nerve bundle. Not to be confused with [[branchOf]].",
    )
    sourcedFrom: Optional[
        Union[List[Union["BrainStructure", str]], "BrainStructure", str]
    ] = Field(
        default=None,
        description="The neurological pathway that originates the neurons.",
    )
    sensoryUnit: Optional[
        Union[
            List[Union["SuperficialAnatomy", "AnatomicalStructure", str]],
            "SuperficialAnatomy",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="The neurological pathway extension that inputs and sends information to the brain or spinal cord.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Muscle import Muscle
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.BrainStructure import BrainStructure
    from pydantic2_schemaorg.SuperficialAnatomy import SuperficialAnatomy



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class BefriendAction(InteractAction):
    """The act of forming a personal connection with someone (object) mutually/bidirectionally/symmetrically.
     Related actions: * [[FollowAction]]: Unlike FollowAction, BefriendAction implies that the connection
     is reciprocal.

    See: https://schema.org/BefriendAction
    Model depth: 4
    """

    type_: str = Field(default="BefriendAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SocialMediaPosting import SocialMediaPosting


class DiscussionForumPosting(SocialMediaPosting):
    """A posting to a discussion forum.

    See: https://schema.org/DiscussionForumPosting
    Model depth: 5
    """

    type_: str = Field(default="DiscussionForumPosting", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime, time
from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class MediaObject(CreativeWork):
    """A media object, such as an image, video, audio, or text object embedded in a web page or a downloadable dataset
     i.e. DataDownload. Note that a creative work may have many media objects associated with it on the same web
     page. For example, a page about a single song (MusicRecording) may have a music video (VideoObject), and a
     high and low bandwidth audio stream (2 AudioObject's).

    See: https://schema.org/MediaObject
    Model depth: 3
    """

    type_: str = Field(default="MediaObject", alias="@type", const=True)
    uploadDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Date (including time if available) when this media object was uploaded to this site.",
    )
    encodingFormat: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Media type typically expressed using a MIME format (see [IANA site](http://www.iana.org/assignments/media-types/media-types.xhtml) and [MDN reference](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types)), e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc. In cases where a [[CreativeWork]] has several media type representations, [[encoding]] can be used to indicate each [[MediaObject]] alongside particular [[encodingFormat]] information. Unregistered or niche encoding and file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia/Wikidata entry.",
    )
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    associatedArticle: Optional[
        Union[List[Union["NewsArticle", str]], "NewsArticle", str]
    ] = Field(
        default=None,
        description="A NewsArticle associated with the Media Object.",
    )
    productionCompany: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The production company or studio responsible for the item, e.g. series, video game, episode etc.",
    )
    interpretedAsClaim: Optional[Union[List[Union["Claim", str]], "Claim", str]] = (
        Field(
            default=None,
            description="Used to indicate a specific claim contained, implied, translated or refined from the content of a [[MediaObject]] or other [[CreativeWork]]. The interpreting party can be indicated using [[claimInterpreter]].",
        )
    )
    contentUrl: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = (
        Field(
            default=None,
            description="Actual bytes of the media object, for example the image file or video file.",
        )
    )
    contentSize: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="File size in (mega/kilo)bytes.",
    )
    playerType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Player type required&#x2014;for example, Flash or Silverlight.",
    )
    startTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    endTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    width: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The width of the item.",
    )
    sha256: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The [SHA-2](https://en.wikipedia.org/wiki/SHA-2) SHA256 hash of the content of the item. For example, a zero-length input has value 'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855'.",
    )
    bitrate: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The bitrate of the media object.",
    )
    embedUrl: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = (
        Field(
            default=None,
            description="A URL pointing to a player for a specific video. In general, this is the information in the ```src``` element of an ```embed``` tag and should not be the same as the content of the ```loc``` tag.",
        )
    )
    requiresSubscription: Optional[
        Union[
            List[Union[StrictBool, "Boolean", "MediaSubscription", str]],
            StrictBool,
            "Boolean",
            "MediaSubscription",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates if use of the media require a subscription (either paid or free). Allowed values are ```true``` or ```false``` (note that an earlier version had 'yes', 'no').",
    )
    height: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The height of the item.",
    )
    encodesCreativeWork: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="The CreativeWork encoded by this media object.",
    )
    regionsAllowed: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The regions where the media is allowed. If not specified, then it's assumed to be allowed everywhere. Specify the countries in [ISO 3166 format](http://en.wikipedia.org/wiki/ISO_3166).",
    )
    ineligibleRegion: Optional[
        Union[
            List[Union[str, "Text", "Place", "GeoShape"]],
            str,
            "Text",
            "Place",
            "GeoShape",
        ]
    ] = Field(
        default=None,
        description="The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed. See also [[eligibleRegion]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.NewsArticle import NewsArticle
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Claim import Claim
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.Distance import Distance
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.MediaSubscription import MediaSubscription
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.GeoShape import GeoShape



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class MisconceptionsHealthAspect(HealthAspectEnumeration):
    """Content about common misconceptions and myths that are related to a topic.

    See: https://schema.org/MisconceptionsHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="MisconceptionsHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class WorkersUnion(Organization):
    """A Workers Union (also known as a Labor Union, Labour Union, or Trade Union) is an organization that promotes
     the interests of its worker members by collectively bargaining with management, organizing, and political
     lobbying.

    See: https://schema.org/WorkersUnion
    Model depth: 3
    """

    type_: str = Field(default="WorkersUnion", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject
from pydantic2_schemaorg.Legislation import Legislation


class LegislationObject(MediaObject, Legislation):
    """A specific object or file containing a Legislation. Note that the same Legislation can be published in multiple
     files. For example, a digitally signed PDF, a plain PDF and an HTML version.

    See: https://schema.org/LegislationObject
    Model depth: 4
    """

    type_: str = Field(default="LegislationObject", alias="@type", const=True)
    legislationLegalValue: Optional[
        Union[List[Union["LegalValueLevel", str]], "LegalValueLevel", str]
    ] = Field(
        default=None,
        description='The legal value of this legislation file. The same legislation can be written in multiple files with different legal values. Typically a digitally signed PDF have a "stronger" legal value than the HTML file of the same act.',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.LegalValueLevel import LegalValueLevel



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Dentistry(MedicalSpecialty):
    """A branch of medicine that is involved in the dental care.

    See: https://schema.org/Dentistry
    Model depth: 6
    """

    type_: str = Field(default="Dentistry", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalStudy import MedicalStudy


class MedicalTrial(MedicalStudy):
    """A medical trial is a type of medical study that uses a scientific process to compare the safety and efficacy
     of medical therapies or medical procedures. In general, medical trials are controlled and subjects are allocated
     at random to the different treatment and/or control groups.

    See: https://schema.org/MedicalTrial
    Model depth: 4
    """

    type_: str = Field(default="MedicalTrial", alias="@type", const=True)
    trialDesign: Optional[
        Union[List[Union["MedicalTrialDesign", str]], "MedicalTrialDesign", str]
    ] = Field(
        default=None,
        description="Specifics about the trial design (enumerated).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalTrialDesign import MedicalTrialDesign



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugPregnancyCategory import DrugPregnancyCategory


class FDAcategoryA(DrugPregnancyCategory):
    """A designation by the US FDA signifying that adequate and well-controlled studies have failed to demonstrate
     a risk to the fetus in the first trimester of pregnancy (and there is no evidence of risk in later trimesters).

    See: https://schema.org/FDAcategoryA
    Model depth: 6
    """

    type_: str = Field(default="FDAcategoryA", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class RespiratoryTherapy(MedicalTherapy, MedicalSpecialty):
    """The therapy that is concerned with the maintenance or improvement of respiratory function (as in patients
     with pulmonary disease).

    See: https://schema.org/RespiratoryTherapy
    Model depth: 6
    """

    type_: str = Field(default="RespiratoryTherapy", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalCondition import MedicalCondition


class MedicalSignOrSymptom(MedicalCondition):
    """Any feature associated or not with a medical condition. In medicine a symptom is generally subjective while
     a sign is objective.

    See: https://schema.org/MedicalSignOrSymptom
    Model depth: 4
    """

    type_: str = Field(default="MedicalSignOrSymptom", alias="@type", const=True)
    possibleTreatment: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A possible treatment to address this condition, sign or symptom.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class TreatmentsHealthAspect(HealthAspectEnumeration):
    """Treatments or related therapies for a Topic.

    See: https://schema.org/TreatmentsHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="TreatmentsHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation


class GolfCourse(SportsActivityLocation):
    """A golf course.

    See: https://schema.org/GolfCourse
    Model depth: 5
    """

    type_: str = Field(default="GolfCourse", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType


class VinylFormat(MusicReleaseFormatType):
    """VinylFormat.

    See: https://schema.org/VinylFormat
    Model depth: 5
    """

    type_: str = Field(default="VinylFormat", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class TouristAttraction(Place):
    """A tourist attraction. In principle any Thing can be a [[TouristAttraction]], from a [[Mountain]] and [[LandmarksOrHistoricalBuildings]]
     to a [[LocalBusiness]]. This Type can be used on its own to describe a general [[TouristAttraction]], or be
     used as an [[additionalType]] to add tourist attraction properties to any other type. (See examples below)

    See: https://schema.org/TouristAttraction
    Model depth: 3
    """

    type_: str = Field(default="TouristAttraction", alias="@type", const=True)
    touristType: Optional[
        Union[List[Union[str, "Text", "Audience"]], str, "Text", "Audience"]
    ] = Field(
        default=None,
        description="Attraction suitable for type(s) of tourist. E.g. children, visitors from a particular country, etc.",
    )
    availableLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[inLanguage]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Language import Language



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class Landform(Place):
    """A landform or physical feature. Landform elements include mountains, plains, lakes, rivers, seascape and
     oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous
     terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins.

    See: https://schema.org/Landform
    Model depth: 3
    """

    type_: str = Field(default="Landform", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EntertainmentBusiness import EntertainmentBusiness


class ArtGallery(EntertainmentBusiness):
    """An art gallery.

    See: https://schema.org/ArtGallery
    Model depth: 5
    """

    type_: str = Field(default="ArtGallery", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Room import Room


class MeetingRoom(Room):
    """A meeting room, conference room, or conference hall is a room provided for singular events such as business
     conferences and meetings (source: Wikipedia, the free encyclopedia, see <a href=\"http://en.wikipedia.org/wiki/Conference_hall\">http://en.wikipedia.org/wiki/Conference_hall</a>).
     <br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated document on the use of schema.org for
     marking up hotels and other forms of accommodations</a>.

    See: https://schema.org/MeetingRoom
    Model depth: 5
    """

    type_: str = Field(default="MeetingRoom", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalObservationalStudyDesign import (
    MedicalObservationalStudyDesign,
)


class CrossSectional(MedicalObservationalStudyDesign):
    """Studies carried out on pre-existing data (usually from 'snapshot' surveys), such as that collected by the
     Census Bureau. Sometimes called Prevalence Studies.

    See: https://schema.org/CrossSectional
    Model depth: 6
    """

    type_: str = Field(default="CrossSectional", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Dataset import Dataset


class DataFeed(Dataset):
    """A single feed providing structured information about one or more entities or topics.

    See: https://schema.org/DataFeed
    Model depth: 4
    """

    type_: str = Field(default="DataFeed", alias="@type", const=True)
    dataFeedElement: Optional[
        Union[
            List[Union[str, "Text", "Thing", "DataFeedItem"]],
            str,
            "Text",
            "Thing",
            "DataFeedItem",
        ]
    ] = Field(
        default=None,
        description="An item within a data feed. Data feeds may have many elements.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.DataFeedItem import DataFeedItem



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class PrognosisHealthAspect(HealthAspectEnumeration):
    """Typical progression and happenings of life course of the topic.

    See: https://schema.org/PrognosisHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="PrognosisHealthAspect", alias="@type", const=True)
